@@ -20,11 +20,9 @@
 #include "pass_struct.h"
 #include "param_struct.h"
 
-int fringe_search (root, pass)
-struct vex *root;
-struct type_pass *pass;
+int fringe_search ( struct vex* root, struct type_pass* pass)
     {
-    int fr, ap, size, oret; 
+    int fr, ap, size, oret, rc; 
 
     struct data_corel *datum;
     complex *sbarray, *sbptr;
@@ -41,20 +39,20 @@ struct type_pass *pass;
     if (generate_cblock (root->ovex, pass) != 0)     
         {
         msg ("Error generating pass block",2);
-        return (1);
+        return (-1);
         }
                                         /* Currently does default filtering */
     if (apply_filter (pass) != 0)
         {
         msg ("Error filtering data", 2);
-        return (1);
+        return (-1);
         }
                                         /* Load in parameters needed for the */
                                         /* fringe search; do all precorrections */
     if (precorrect(root->ovex, pass) != 0)
         {
         msg ("Error precorrecting data", 2);
-        return (1);
+        return (-1);
         }
                                         /* Allocate memory for SBD functions */
                                         /* Should allocate only for unflagged */
@@ -81,14 +79,29 @@ struct type_pass *pass;
             sbptr += 2*param.nlags;
             }
                                         // perform ionospheric search
-    if (ion_search (pass))
+    if (param.ion_smooth)
+        {                               // fine search using smoothed coarse points
+        rc = ion_search_smooth (pass);
+        if (rc < 0)
             {
-            char *pols[] = { "LL", "RR", "LR", "RL" };
-            char *zpol = (pass->pol < 0 || pass->pol > 3) ? "??" : pols[pass->pol];
-            msg ("Error return from ion_search on %c%c group %c pol %s", 2,
-                  param.baseline[0], param.baseline[1], pass->pass_data[0].fgroup, zpol);
-            return (1);
+            msg ("Error return from ion_search_smooth", 2);
+            return (-1);
             }
+        else if (rc > 0)                // non-fatal condition
+            return (rc);
+        }
+    else                                // 3-tiered non-smoothed ion search
+        {
+        rc = ion_search (pass);
+        if (rc < 0)
+            {
+            msg ("Error return from ion_search", 2);
+            return (-1);
+            }
+        else if (rc > 0)                // non-fatal condition
+            return (rc);
+        }
+
                                         /* Write the fringe file to disk, with */
                                         /* or without traditional fringe plot */
                                         /* attached, depending on control info */
@@ -98,7 +111,7 @@ struct type_pass *pass;
     if (oret > 0)
         {
         msg ("Error writing results", 2);
-        return (1);
+        return (-1);
         }
     else if (oret < 0) return (-1);
                                         /* Free allocated memory */
