@@ -29,7 +29,7 @@ int generate_graphs (struct scan_struct *root,
     char buf[2560], device[256];
     double drate, mbd, sbd;
     struct tm *gmtime();
-    float xr[2*MAXMAX], yr[2*MAXMAX], zr[2*MAXMAX];
+    static float xr[2*MAXMAX], yr[2*MAXMAX], zr[2*MAXMAX];
     float xmin, xmax, ymin, ymax, plotwidth;
     float xpos, offset, lwid, yplace;
     double max_dr_win, max_sb_win, max_mb_win;
@@ -41,7 +41,7 @@ int generate_graphs (struct scan_struct *root,
     int nlsb, nusb, izero;
                                         /* Build the proper device string for */
                                         /* vertically oriented color postscript */
-    sprintf (device, "%s/vcps", ps_file);
+    sprintf (device, "%s/VCPS", ps_file);
                                         /* Open the pgplot device */
     if (cpgopen (device) <= 0)
         {
